"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReadPDFForm = void 0;
const PDFJS = __importStar(require("pdfjs-dist/legacy/build/pdf.js"));
class ReadPDFForm {
    constructor() {
        this.description = {
            displayName: 'Read PDF Form data',
            name: 'readPDFForm',
            icon: 'fa:file-pdf',
            group: ['input'],
            version: 1,
            description: 'Reads a PDF Form and extracts its content',
            defaults: {
                name: 'Read PDF Form',
                color: '#003355',
            },
            inputs: ['main'],
            outputs: ['main'],
            properties: [
                {
                    displayName: 'Binary Property',
                    name: 'binaryPropertyName',
                    type: 'string',
                    default: 'data',
                    required: true,
                    description: 'Name of the binary property from which to read the PDF file',
                },
            ],
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const length = items.length;
        let item;
        for (let itemIndex = 0; itemIndex < length; itemIndex++) {
            try {
                item = items[itemIndex];
                const binaryPropertyName = this.getNodeParameter('binaryPropertyName', itemIndex);
                if (item.binary === undefined) {
                    item.binary = {};
                }
                const binaryData = await this.helpers.getBinaryDataBuffer(itemIndex, binaryPropertyName);
                returnData.push({
                    binary: item.binary,
                    json: await PDF(binaryData),
                });
            }
            catch (error) {
                if (this.continueOnFail()) {
                    returnData.push({
                        json: {
                            error: error.message,
                        },
                        pairedItem: {
                            item: itemIndex,
                        },
                    });
                    continue;
                }
                throw error;
            }
        }
        return this.prepareOutputData(returnData);
    }
}
exports.ReadPDFForm = ReadPDFForm;
const DEFAULT_OPTIONS = {
    max: 0,
};
async function PDF(dataBuffer) {
    const isDebugMode = false;
    const ret = {
        numpages: 0,
        numrender: 0,
        info: {},
        metadata: {},
        text: "",
        version: "",
        formData: {},
    };
    ret.version = PDFJS.version;
    const loadingTask = PDFJS.getDocument(dataBuffer);
    const doc = await loadingTask.promise;
    ret.numpages = doc.numPages;
    const metaData = await doc.getMetadata().catch((err) => {
        return err;
    });
    ret.info = metaData ? metaData.info : {};
    ret.metadata = metaData ? metaData.metadata : {};
    if (ret.info != null && metaData.info.IsAcroFormPresent) {
        const formData = await doc.getFieldObjects().catch((err) => {
            return err;
        });
        ret.formData = formData ? formData : {};
    }
    let counter = 0;
    counter = counter > doc.numPages ? doc.numPages : counter;
    ret.text = "";
    for (let i = 1; i <= counter; i++) {
        const pageText = doc.getPage(i).then((pageData) => render_page(pageData)).catch((err) => {
            return err;
        });
        ret.text = `${ret.text}\n\n${pageText}`;
    }
    ret.numrender = counter;
    doc.destroy();
    return ret;
}
async function render_page(pageData) {
    const textContent = await pageData.getTextContent();
    let lastY, text = '';
    for (const item of textContent.items) {
        if (lastY === item.transform[5] || !lastY) {
            text += item.str;
        }
        else {
            text += '\n' + item.str;
        }
        lastY = item.transform[5];
    }
    return text;
}
//# sourceMappingURL=ReadPDFForm.node.js.map